Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1286)

Unified Diff: recipes/fletch.py

Issue 1317833004: Add fetch recipe for fletch (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/depot_tools
Patch Set: Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: recipes/fletch.py
diff --git a/recipes/dart.py b/recipes/fletch.py
similarity index 80%
copy from recipes/dart.py
copy to recipes/fletch.py
index 2b4d78c0f25b820b9e43b2e70512cd0051737434..1938ea7e4173b49f95e9d55d0604abdd1e9cce69 100644
--- a/recipes/dart.py
+++ b/recipes/fletch.py
@@ -6,17 +6,16 @@ import sys
import recipe_util # pylint: disable=F0401
-
# This class doesn't need an __init__ method, so we disable the warning
# pylint: disable=W0232
-class Dart(recipe_util.Recipe):
- """Basic Recipe class for Dart."""
+class Fletch(recipe_util.Recipe):
+ """Basic Recipe class for Fletch."""
@staticmethod
def fetch_spec(props):
- url = 'https://github.com/dart-lang/sdk.git'
+ url = 'https://github.com/dart-lang/fletch.git'
solution = {
- 'name' :'sdk',
+ 'name' :'fletch',
'url' : url,
'deps_file': 'DEPS',
'managed' : False,
@@ -35,11 +34,11 @@ class Dart(recipe_util.Recipe):
@staticmethod
def expected_root(_props):
- return 'sdk'
+ return 'fletch'
def main(argv=None):
- return Dart().handle_args(argv)
+ return Fletch().handle_args(argv)
if __name__ == '__main__':
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698